intelmq.bots.parsers.shodan package — intelmq 3.0.0.alpha.1 documentation

# intelmq.bots.parsers.shodan package

## Submodules

## intelmq.bots.parsers.shodan.parser module

Shodan Stream Parser

Copyright (C) 2018 by nic.at GmbH

`intelmq.bots.parsers.shodan.parser.` `BOT`

  alias of `intelmq.bots.parsers.shodan.parser.ShodanParserBot`

class `intelmq.bots.parsers.shodan.parser.` `ShodanParserBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.Bot`

  Parse Shodan data collected via the Shodan API

  `apply_mapping`(mapping, data, key_path=())
  `ignore_errors` = True
  `minimal_mode` = False
  `process`()

## Module contents